akhdefo_functions.DynamicChangeDetection — Akhdefo software documentation

# akhdefo_functions.DynamicChangeDetection

akhdefo_functions.DynamicChangeDetection(Path_working_Directory='', Path_UDM2_folder='', Path_to_DEMFile='', Coh_Thresh=0.75, vel_thresh=0.063, udm_mask_option=False, cmap='jet', Median_Filter=False, Set_fig_MinMax=False, show_figure=False, plot_option='origional', xres=10, yres=10)

  This program calculates optical flow velocity from triplets of daily optical satellite images. Final Timeseris products will be a shapefile format using Time_Series function after stackprep step.

  ## Parameters

  Path_working_Directory : str

  Path_UDM2_folder : str

  Path_to_DEMFile : str

  Coh_Thresh : float

  vel_thresh : float

  udm_mask_option : bool

  cmap : str

  Median_Filter : bool

  Set_fig_MinMax : bool

  show_figure : bool

  plot_optionstr

    “origional”, “resampled”

  xres : int

  yres : int

  ## Returns

  Rasters

    velocity in X direction(EW) Velocity in Y direction(NS)

  Figures

    Initial Timesereis Figures (those figures are only intermediate products needs calibration)